radioapp/radiowidgets/inc/radiowindow.h
changeset 32 189d20c34778
parent 28 075425b8d9a4
child 38 f8c3d4e6102c
--- a/radioapp/radiowidgets/inc/radiowindow.h	Fri Jun 11 13:38:32 2010 +0300
+++ b/radioapp/radiowidgets/inc/radiowindow.h	Wed Jun 23 18:12:57 2010 +0300
@@ -21,7 +21,7 @@
 // System includes
 #include <HbMainWindow>
 #include <HbEffect>
-#include <QPointer>
+#include <QWeakPointer>
 #include <QScopedPointer>
 #include <QSharedPointer>
 #include <qsysteminfo.h>
@@ -39,11 +39,11 @@
 typedef QScopedPointer<HbVolumeSliderPopup> VolumeSliderPtr;
 
 /**
  * QPointer is used to store the views because it tracks the deletion of the object and nulls
  * the reference. Transient view like RadioHistoryView is destroyed after they are closed
- * and QPointer will notice it.
+ * and QWeakPointer will notice it.
  */
-typedef QPointer<RadioViewBase> ViewPtr;
+typedef QWeakPointer<RadioViewBase> ViewPtr;
 
 // Class declaration
 class WIDGETS_DLL_EXPORT RadioWindow : public HbMainWindow
@@ -39,11 +39,11 @@
 
 /**
- * QPointer is used to store the views because it tracks the deletion of the object and nulls
+ * QWeakPointer is used to store the views because it tracks the deletion of the object and nulls
  * the reference. Transient view like RadioHistoryView is destroyed after they are closed